==> panopoly-7.x-1.25-no-core.tar.gz: panopoly/README.md <==

CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Installation
 * Documentation
 * Automated tests


INTRODUCTION
------------

Current Maintainers: Matt Cheney <matt@getpantheon.com>
                     David Snopek <dsnopek@gmail.com>
                     Tom Kirkpatrick <tom@systemseed.com>

Panopoly is powerful base distribution of Drupal powered by lots of Chaos Tools
and Panels magic. The distribution is designed to be both a general foundation
for site building and a base framework upon which to build other Drupal
distributions. Panopoly is:

 * Panels Powered - Woven together functionality from Panels, the Panels
   In-Place-Editor, Fieldable Panel Panes, PM Existing Pages, Panelizer and a
   lot of extra special sauce.

 * Responsive - Over two dozen cross-browser, responsive layouts and several
   responsive image styles are included to aid in site building and allow your
   site to work seamlessly on mobile devices.

 * In-Place Page Building - Drag and drop customization of pages and nodes.
   Easily switch layouts, modify Views and Panels settings, change styles, and
   add generic widgets to display text, images, links, maps, submenus, video
   and spotlights across your site. No backend administration required!

 * Admin Experience - Vastly improved site and content management experience,
   featuring a redesigned node add/edit page and a fully loaded, media enabled
   TinyMCE WYSIWYG.

 * Apps Powered - Panopoly can be extended through various Panopoly Apps
   delivered by the Panopoly App server.

 * To make everything happen, Panopoly bundles a currated set of contributed
   modules and third party libraries with its own custom modules including
   Panopoly Admin, Panopoly Core, Panopoly Images, Panopoly Magic, Panopoly
   Pages, Panopoly Search, Panopoly Theme, Panopoly Users, Panopoly Widgets,
   and Panopoly WYSIWYG.


INSTALLATION
------------

@see https://drupal.org/node/1651082


DOCUMENTATION
-------------

@see https://drupal.org/node/1651048

AUTOMATED TESTS
---------------

We use Travis-CI.org to run automated tests after every commit.

[![Build Status](https://travis-ci.org/panopoly/panopoly.svg?branch=7.x-1.x)](http://travis-ci.org/panopoly/panopoly)

@see https://www.drupal.org/node/2271009

==> panopoly-7.x-1.48-no-core.tar.gz: panopoly/README.md <==

CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Installation
 * Documentation
 * Automated tests


INTRODUCTION
------------

Current Maintainers: Matt Cheney <matt@getpantheon.com>
                     David Snopek <dsnopek@gmail.com>
                     Tom Kirkpatrick <tom@systemseed.com>

Panopoly is a powerful base distribution of Drupal powered by lots of
Chaos Tools and Panels magic. The distribution is designed to be both
a general foundation for site building and a base framework upon which
to build other Drupal distributions. Panopoly is:

 * Panels Powered - Woven together functionality from Panels, the Panels
   In-Place-Editor, Fieldable Panel Panes, PM Existing Pages, Panelizer and a
   lot of extra special sauce.

 * Responsive - Over two dozen cross-browser, responsive layouts and several
   responsive image styles are included to aid in site building and allow your
   site to work seamlessly on mobile devices.

 * In-Place Page Building - Drag and drop customization of pages and nodes.
   Easily switch layouts, modify Views and Panels settings, change styles, and
   add generic widgets to display text, images, links, maps, submenus, video
   and spotlights across your site. No backend administration required!

 * Admin Experience - Vastly improved site and content management experience,
   featuring a redesigned node add/edit page and a fully loaded, media enabled
   TinyMCE WYSIWYG.

 * Apps Powered - Panopoly can be extended through various Panopoly Apps
   delivered by the Panopoly App server.

 * To make everything happen, Panopoly bundles a currated set of contributed
   modules and third party libraries with its own custom modules including
   Panopoly Admin, Panopoly Core, Panopoly Images, Panopoly Magic, Panopoly
   Pages, Panopoly Search, Panopoly Theme, Panopoly Users, Panopoly Widgets,
   and Panopoly WYSIWYG.


INSTALLATION
------------

@see https://drupal.org/node/1651082


DOCUMENTATION
-------------

@see https://drupal.org/node/1651048

AUTOMATED TESTS
---------------

We use Travis-CI.org to run automated tests after every commit.

[![Build Status](https://travis-ci.org/panopoly/panopoly.svg?branch=7.x-1.x)](http://travis-ci.org/panopoly/panopoly)

@see https://www.drupal.org/node/2271009
